@@ -11,7 +11,6 @@ __license__ = 'GNU GPL v3.0'
 import re
 import logging
 from smtplib import SMTP, SMTPException
-from os.path import getmtime
 from time import time
 from pathlib import Path
 from openpyxl import load_workbook
@@ -31,9 +30,8 @@ class SourceDevice:
         self.log_file_path = log_path
         self.log_parent_path = log_path.parent
         self.log_filename = log_path.name
-        self.log_modified_time = getmtime(log_path)
+        self.log_modified_time = log_path.stat().st_mtime
         self.device_name = None
-        self.ip, self.netmask, self.gateway = self.parse_net_info
         self.site_name = None
         self.serial_number = None
         self.error_list = []
@@ -68,29 +66,6 @@ class SourceDevice:
 
         return device_type
 
-    def parse_net_info(self):
-        """
-        A function to verify the management network information in the startup config.
-        Reference information was pulled from the documentation provided the Project Engineers
-        and is not guaranteed or intended to cover every project.
-        """
-        trigger = 0
-        with open(self.log_file_path) as open_file:
-            for line in open_file.readlines():
-                if 'interface Vlan31' in line:
-                    trigger = 1
-                    continue
-                if trigger == 1 and 'ip address ' in line:
-                    net_info = line.strip().split(' ')
-                    ip = net_info[2]
-                    netmask = net_info[3]
-                    trigger += 1
-                    continue
-                if trigger == 2 and 'ip default-gateway' in line:
-                    gateway = line.strip().split(' ')[-1]
-
-            return ip, netmask, gateway
-
     @property
     def startup_config(self):
         """
@@ -120,6 +95,39 @@ class SourceDevice:
             match = False
         return match
 
+
+class NetworkedSourceDevice(SourceDevice):
+    """
+    This is a subclass of SourceDevice that adds networking attributes.
+    """
+    def __init__(self, log_path: Path):
+        super().__init__(log_path)
+        self.ip, self.netmask, self.gateway = self.parse_net_info()
+
+
+    def parse_net_info(self):
+        """
+        A function to verify the management network information in the startup config.
+        Reference information was pulled from the documentation provided the Project Engineers
+        and is not guaranteed or intended to cover every project.
+        """
+        trigger = 0
+        with open(self.log_file_path) as open_file:
+            for line in open_file.readlines():
+                if 'interface Vlan31' in line:
+                    trigger = 1
+                    continue
+                if trigger == 1 and 'ip address ' in line:
+                    net_info = line.strip().split(' ')
+                    ip = net_info[2]
+                    netmask = net_info[3]
+                    trigger += 1
+                    continue
+                if trigger == 2 and 'ip default-gateway' in line:
+                    gateway = line.strip().split(' ')[-1]
+
+            return ip, netmask, gateway
+
     def check_device_net_info(self, ip_info: dict):
         error_codes = {
             1: 'does not have the correct IP address.',
